import java.util.Properties;
import java.io.*;

/**
 * CivLogProperties handles custom Properties
 *
 * The following properties are set:
 *   civlog.dynamicRescale=false/
 */
public class CivLogProperties {
  private static final String propFile = ".civlogProperties";
  private static Properties prop = null;

  static {
    Debug.trace ("CivLogProperties: static initializer");
    if (! loadProperties())
      System.out.println("Error loading Properties");
  }
  
  /*
    Key                                Meaning
    "os.arch"                          Operating system architecture
    "os.name"                          Operating system name
    "os.version"                       Operating system version
    "path.separator"                   Path separator (for example, ":")
    "user.dir"                         User's current working directory
    "user.home"                        User home directory
    "user.name"                        User account name
  */
  
  // just for info
  public static void printSystemProperties() {
    System.out.println ("--- System Properties ---");
    System.out.println ("os.arch: "+ System.getProperty("os.arch"));
    System.out.println ("os.name: "+ System.getProperty("os.name"));
    System.out.println ("os.version: "+ System.getProperty("os.version"));
    System.out.println ("user.dir: "+ System.getProperty("user.dir"));
    System.out.println ("user.home: "+ System.getProperty("user.home"));
    System.out.println ("user.name: "+ System.getProperty("user.name"));
    System.out.println ("--- End of System Info ---");
  }

  /** find out where the properties are saved
      int case user.home is not available on Win9x add code here
  */
  public static String getProperty (String p) {
    return prop.getProperty (p);
  }

  public static void setProperty (String k, String v) {
    prop.setProperty (k, v);
    saveProperties();
  }

  private static String getPropertyPath () {
    // return (System.getProperty("user.home"));
    return  (System.getProperty("user.home") + System.getProperty("file.separator") + propFile);
  }

  // called from Viewer to load the propertiesFile
  private static boolean loadProperties () {
    Debug.trace ("CivLogProperties: loadProperties()");
    String propDir = getPropertyPath();
    if (propDir == null) 
      return false;

    Properties props = new Properties ();
    // load custom properties from file into it
    try {
      props.load (new BufferedInputStream (new FileInputStream (propDir)));
    } catch (java.io.FileNotFoundException ex) {
      System.out.println ("Error (CivLogProperties): loadProperties, FileNotFoundException\n"+
                          "The property-file ("+propDir+propFile+") was not found.\n"+
                          "If this is the first time you start CivLog this is ok and\n"+
                          "it will be created for you.\n"+
                          "If this happens often, please contact the authors, you found a bug!");
    } catch (java.io.IOException ex) {
      System.out.println ("Error (CivLogProperties): loadProperties, IOException");
    }
    // set these combined properties as the System properties, may be useful?
    // System.setProperties (props);
    prop = props;

    return true;
    } // loadProperties


    /** saves properties in a property file */
    public static boolean saveProperties () {
      Debug.trace ("CivLogProperties: saveProperties");
      if (!createPropertyFile (prop)) {
        System.out.println ("Error (CivLogProperties): cannot save properties, createPropertyFile returns false");
        return false;
      }
      return true;
    }

    // creates the propertyFile with the properties specified in newProp
    static boolean createPropertyFile (Properties newProp) {
      String propDir = getPropertyPath();
      
      FileOutputStream defaultsOut = null;
      try {
        defaultsOut = new FileOutputStream(propDir);
      } catch (Exception ex) {
        System.out.println ("Error (CivLogProperties): could not open "+propDir);
        return false;
      }
      
      newProp.save (defaultsOut, "---=== CivLog Properties ===---");
      try {
        defaultsOut.close();
      } catch  (Exception ex) {
        System.out.println ("Error (CivLogProperties): could not close file "+propDir);
        return false;
      }

      if (loadProperties() != true) {
        System.out.println ("Error (CivLogProperties): loading of Properties failed after writing.");
        return false;
      }
      
      return true;
    }
  
}
